==> mdt-ocl-Update-6.6.0.zip: org/eclipse/ocl/pivot/internal/attributes/DataTypeAttribution.java <==
/*******************************************************************************
 * Copyright (c) 2012, 2018 Willink Transformations and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     E.D.Willink - initial API and implementation
 *******************************************************************************/
package org.eclipse.ocl.pivot.internal.attributes;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.ocl.pivot.DataType;
import org.eclipse.ocl.pivot.Type;
import org.eclipse.ocl.pivot.internal.scoping.AbstractAttribution;
import org.eclipse.ocl.pivot.internal.scoping.Attribution;
import org.eclipse.ocl.pivot.internal.scoping.EnvironmentView;
import org.eclipse.ocl.pivot.internal.scoping.ScopeView;

public class DataTypeAttribution extends AbstractAttribution
{
	public static final DataTypeAttribution INSTANCE = new DataTypeAttribution();

	@Override
	public ScopeView computeLookup(@NonNull EObject target, @NonNull EnvironmentView environmentView, @NonNull ScopeView scopeView) {
		DataType targetElement = (DataType) target;
		Type behavioralType = targetElement.getBehavioralClass();
		Attribution attribution;
		if (behavioralType != null) {
			attribution = environmentView.getAttribution(behavioralType);
		}
		else {
			attribution = ClassAttribution.INSTANCE;
		}
		environmentView.addAllTemplateParameters(targetElement);
		if (attribution != this) {
			return attribution.computeLookup(target, environmentView, scopeView);
		}
		else {
			return scopeView.getParent();
		}
	}
}

==> mdt-ocl-Update-6.14.0.zip: org/eclipse/ocl/pivot/internal/attributes/DataTypeAttribution.java <==
/*******************************************************************************
 * Copyright (c) 2012, 2018 Willink Transformations and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     E.D.Willink - initial API and implementation
 *******************************************************************************/
package org.eclipse.ocl.pivot.internal.attributes;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.ocl.pivot.DataType;
import org.eclipse.ocl.pivot.Type;
import org.eclipse.ocl.pivot.internal.scoping.AbstractAttribution;
import org.eclipse.ocl.pivot.internal.scoping.Attribution;
import org.eclipse.ocl.pivot.internal.scoping.EnvironmentView;
import org.eclipse.ocl.pivot.internal.scoping.ScopeView;

public class DataTypeAttribution extends AbstractAttribution
{
	public static final DataTypeAttribution INSTANCE = new DataTypeAttribution();

	@Override
	public ScopeView computeLookup(@NonNull EObject target, @NonNull EnvironmentView environmentView, @NonNull ScopeView scopeView) {
		DataType targetElement = (DataType) target;
		Type resolvedClass = targetElement.getBehavioralClass();
		Attribution attribution;
		if (resolvedClass != null) {
			attribution = environmentView.getAttribution(resolvedClass);
		}
		else {
			attribution = ClassAttribution.INSTANCE;
		}
		environmentView.addAllTemplateParameters(targetElement);
		if (attribution != this) {
			return attribution.computeLookup(target, environmentView, scopeView);
		}
		else {
			return scopeView.getParent();
		}
	}
}
